@@ -31,11 +31,6 @@ void HeaderTest::testIdentHeader()
     QCOMPARE(h->identifiers().first(), QByteArray("1162746587.784559.5038.nullmailer@svn.kde.org"));
     QCOMPARE(h->asUnicodeString(), QString::fromLatin1("<1162746587.784559.5038.nullmailer@svn.kde.org>"));
     QVERIFY(!h->isEmpty());
-
-    // clearing a header
-    h->clear();
-    QVERIFY(h->isEmpty());
-    QVERIFY(h->identifiers().isEmpty());
     delete h;
 
     // parse multiple identifiers
@@ -88,10 +83,6 @@ void HeaderTest::testAddressListHeader()
     QCOMPARE(h->displayNames().first(), QLatin1StringView("joe@where.test"));
     QCOMPARE(h->displayString(), QLatin1StringView("joe@where.test"));
     QCOMPARE(h->asUnicodeString(), QLatin1StringView("joe@where.test"));
-
-    // clearing a header
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parsing and re-assembling a single address with display name
@@ -434,10 +425,6 @@ void HeaderTest::testMailCopiesToHeader()
     QVERIFY(!h->alwaysCopy());
     QVERIFY(h->neverCopy());
     QCOMPARE(h->as7BitString(), QByteArray("Mail-Copies-To: nobody"));
-
-    // clear header
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse copy to poster
@@ -504,10 +491,6 @@ void HeaderTest::testParametrizedHeader()
     QCOMPARE(h->parameter("filename"), QLatin1StringView("bla.jpg"));
     QCOMPARE(h->parameter("FILENAME"), QLatin1StringView("bla.jpg"));
     QCOMPARE(h->as7BitString(false), QByteArray("filename=\"bla.jpg\""));
-
-    // clear again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse a parameter list
@@ -634,10 +617,6 @@ void HeaderTest::testContentTypeHeader()
     h->setId("bla");
     h->setCharset("us-ascii");
     QCOMPARE(h->as7BitString(false), QByteArray("text/plain; charset=\"us-ascii\"; id=\"bla\""));
-
-    // clear header
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse a complete header
@@ -700,10 +679,6 @@ void HeaderTest::testTokenHeader()
     h->setToken("bla");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->as7BitString(false), QByteArray("bla"));
-
-    // clear it again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse a header
@@ -718,18 +693,11 @@ void HeaderTest::testContentTransferEncoding()
 {
     ContentTransferEncoding *h;
 
-    // empty header
-    h = new ContentTransferEncoding();
-    QVERIFY(h->isEmpty());
-
     // set an encoding
+    h = new ContentTransferEncoding();
     h->setEncoding(CEbinary);
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->as7BitString(true), QByteArray("Content-Transfer-Encoding: binary"));
-
-    // clear again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse a header
@@ -758,10 +726,6 @@ void HeaderTest::testPhraseListHeader()
     QCOMPARE(phrases.takeFirst(), QLatin1StringView("foo"));
     QCOMPARE(phrases.takeFirst(), QLatin1StringView("bar"));
     QCOMPARE(h->as7BitString(false), QByteArray("foo, bar"));
-
-    // clear header
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // TODO: encoded/quoted phrases
@@ -779,10 +743,6 @@ void HeaderTest::testDotAtomHeader()
     h->from7BitString("1.0 (mime version)");
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->asUnicodeString(), QLatin1StringView("1.0"));
-
-    // clear again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // TODO: more complex atoms
@@ -803,10 +763,6 @@ void HeaderTest::testDateHeader()
     QCOMPARE(h->dateTime().time(), QTime(9, 55, 6));
     QCOMPARE(h->dateTime().offsetFromUtc(), -6 * 3600);
     QCOMPARE(h->as7BitString(), QByteArray("Date: Fri, 21 Nov 1997 09:55:06 -0600"));
-
-    // clear it again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // white spaces and comment (from RFC 2822, Appendix A.5)
@@ -953,10 +909,6 @@ void HeaderTest::testLinesHeader()
     h->setNumberOfLines(5);
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->as7BitString(), QByteArray("Lines: 5"));
-
-    // clear again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse header with comment
@@ -982,10 +934,6 @@ void HeaderTest::testNewsgroupsHeader()
     h->setGroups(groups);
     QVERIFY(!h->isEmpty());
     QCOMPARE(h->as7BitString(), QByteArray("Newsgroups: gmane.comp.kde.devel.core,gmane.comp.kde.devel.buildsystem"));
-
-    // and clear again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse a header
@@ -1021,10 +969,6 @@ void HeaderTest::testControlHeader()
     QVERIFY(!h->isEmpty());
     QVERIFY(h->isCancel());
     QCOMPARE(h->as7BitString(),  QByteArray("Control: cancel <foo@bar>"));
-
-    // clear again
-    h->clear();
-    QVERIFY(h->isEmpty());
     delete h;
 
     // parse a control header
@@ -1095,17 +1039,13 @@ void HeaderTest::testInvalidQEncoding_data()
 
 void HeaderTest::testInvalidQEncoding()
 {
-    using namespace HeaderParsing;
     QFETCH(QString, encodedWord);
 
-    QByteArray tmp = encodedWord.toLatin1();
-    const char *data = tmp.data();
-    const char *start = data + 1;
-    const char *end = data + strlen(data);
-    QString result;
-    QByteArray language;
-    QByteArray usedCS;
-    QVERIFY(!parseEncodedWord(start, end, result, language, usedCS));
+    QByteArray tmp = encodedWord.toLatin1() + " <noreply@kde.org>";
+    Headers::From hdr;
+    hdr.from7BitString(tmp);
+    QCOMPARE(hdr.mailboxes().at(0).address(), "noreply@kde.org");
+    QCOMPARE(hdr.mailboxes().at(0).name(), encodedWord); // invalid name is not decoded and preserved as-is
 }
 
 void HeaderTest::testMissingQuotes()
