@@ -28,7 +28,6 @@
 
 #include <KCodecs>
 
-#include <QDebug>
 #include <QStringDecoder>
 #include <QStringEncoder>
 
@@ -369,7 +368,7 @@ QByteArray Content::decodedContent() const
     return ret;
 }
 
-QString Content::decodedText(bool trimText, bool removeTrailingNewlines) const
+QString Content::decodedText(DecodedTextTrimOption trimOption) const
 {
     if (!d_ptr->decodeText(this)) {   //this is not a text content !!
       return {};
@@ -385,10 +384,10 @@ QString Content::decodedText(bool trimText, bool removeTrailingNewlines) const
 
     QString s = codec.decode(d_ptr->body);
 
-    if (trimText || removeTrailingNewlines) {
+    if (trimOption != NoTrim) {
         qsizetype i;
         for (i = s.length() - 1; i >= 0; --i) {
-            if (trimText) {
+            if (trimOption == TrimSpaces) {
                 if (!s[i].isSpace()) {
                     break;
                 }
@@ -446,15 +445,15 @@ const Content *Content::textContent() const
     return nullptr;
 }
 
-QList<Content *> Content::attachments() const {
+QList<Content *> Content::attachments() {
     QList<Content *> result;
 
     auto ct = contentType();
     if (ct && ct->isMultipart() &&
         !ct->isSubtype("related") /* && !ct->isSubtype("alternative")*/) {
-        const QList<Content *> contentsList = contents();
-        result.reserve(contentsList.count());
-        for (Content *child : contentsList) {
+        const auto contentsList = contents();
+        result.reserve(contentsList.size());
+        for (auto child : contentsList) {
             if (isAttachment(child)) {
                 result.push_back(child);
             } else {
@@ -466,7 +465,10 @@ QList<Content *> Content::attachments() const {
     return result;
 }
 
-QList<Content *> Content::contents() const { return d_ptr->contents(); }
+QList<Content *> Content::contents()
+{
+    return d_ptr->contents();
+}
 
 void Content::replaceContent(Content *oldContent, Content *newContent)
 {
@@ -558,12 +560,13 @@ void Content::changeEncoding(Headers::contentEncoding e)
     }
 }
 
-QList<Headers::Base *> Content::headers() const { return d_ptr->headers; }
-
-Headers::Base *Content::headerByType(const char *type) const
+QList<Headers::Base *> Content::headers()
 {
-    Q_ASSERT(type  && *type);
+    return d_ptr->headers;
+}
 
+Headers::Base *Content::headerByType(QByteArrayView type) const
+{
     for (Headers::Base *h : std::as_const(d_ptr->headers)) {
         if (h->is(type)) {
             return h; // Found.
@@ -573,9 +576,8 @@ Headers::Base *Content::headerByType(const char *type) const
     return nullptr; // Not found.
 }
 
-QList<Headers::Base *> Content::headersByType(const char *type) const {
-    Q_ASSERT(type && *type);
-
+QList<Headers::Base *> Content::headersByType(QByteArrayView type) const
+{
     QList<Headers::Base *> result;
 
     for (Headers::Base *h : std::as_const(d_ptr->headers)) {
@@ -600,7 +602,7 @@ void Content::appendHeader(Headers::Base *h)
     d->headers.append(h);
 }
 
-bool Content::removeHeader(const char *type)
+bool Content::removeHeader(QByteArrayView type)
 {
     Q_D(Content);
     const auto endIt = d->headers.end();
@@ -615,7 +617,7 @@ bool Content::removeHeader(const char *type)
     return false;
 }
 
-bool Content::hasHeader(const char* type) const
+bool Content::hasHeader(QByteArrayView type) const
 {
     return headerByType(type) != nullptr;
 }
@@ -792,13 +794,12 @@ ContentIndex Content::index() const
     return indexForContent(const_cast<Content *>(this));
 }
 
-Message::Ptr Content::bodyAsMessage() const
+Message::Ptr Content::bodyAsMessage()
 {
     if (bodyIsMessage() && d_ptr->bodyAsMessage) {
         return d_ptr->bodyAsMessage;
-    } else {
-      return {};
     }
+    return {};
 }
 
 bool Content::bodyIsMessage() const
@@ -849,8 +850,8 @@ bool ContentPrivate::parseUuencoded(Content *q)
         return false; // Parsing failed.
     }
 
+    q->removeHeader<Headers::ContentType>();
     Headers::ContentType *ct = q->contentType();
-    ct->clear();
 
     if (uup.isPartial()) {
         // This seems to be only a part of the message, so we treat it as "message/partial".
@@ -904,8 +905,8 @@ bool ContentPrivate::parseYenc(Content *q)
         return false; // Parsing failed.
     }
 
+    q->removeHeader<Headers::ContentType>();
     Headers::ContentType *ct = q->contentType();
-    ct->clear();
 
     if (yenc.isPartial()) {
         // Assume there is exactly one decoded part.  Treat this as "message/partial".
