@@ -31,7 +31,6 @@
 #include "util.h"
 #include "util_p.h"
 #include "codecs_p.h"
-#include "content.h"
 #include "headerfactory_p.h"
 #include "kmime_debug.h"
 #include "warning_p.h"
@@ -43,7 +42,7 @@
 
 // macro to generate a default constructor implementation
 #define kmime_mk_trivial_ctor( subclass, baseclass )                  \
-    subclass::subclass() : baseclass()           \
+    subclass::subclass()           \
     {                                                                     \
     }                                                                     \
     \
@@ -125,14 +124,9 @@ const char *Base::type() const
     return "";
 }
 
-bool Base::is(const char *t) const
+bool Base::is(QByteArrayView t) const
 {
-    return qstricmp(t, type()) == 0;
-}
-
-bool Base::isMimeHeader() const
-{
-    return qstrnicmp(type(), "Content-", 8) == 0;
+    return t.compare(type(), Qt::CaseInsensitive) == 0;
 }
 
 QByteArray Base::typeIntro() const
@@ -191,12 +185,6 @@ QString Unstructured::asUnicodeString() const
     return d_func()->decoded;
 }
 
-void Unstructured::clear()
-{
-    Q_D(Unstructured);
-    d->decoded.truncate(0);
-}
-
 bool Unstructured::isEmpty() const
 {
     return d_func()->decoded.isEmpty();
@@ -308,12 +296,6 @@ QString MailboxList::asUnicodeString() const
     return Mailbox::listToUnicodeString(d->mailboxList);
 }
 
-void MailboxList::clear()
-{
-    Q_D(MailboxList);
-    d->mailboxList.clear();
-}
-
 bool MailboxList::isEmpty() const
 {
     return d_func()->mailboxList.isEmpty();
@@ -379,6 +361,12 @@ Types::Mailbox::List MailboxList::mailboxes() const
     return d_func()->mailboxList;
 }
 
+void MailboxList::setMailboxes(const Types::Mailbox::List &mailboxes)
+{
+    Q_D(MailboxList);
+    d->mailboxList = mailboxes;
+}
+
 bool MailboxList::parse(const char *&scursor, const char *const send,
                         bool isCRLF)
 {
@@ -483,12 +471,6 @@ QString AddressList::asUnicodeString() const
     return rv.join(QLatin1StringView(", "));
 }
 
-void AddressList::clear()
-{
-    Q_D(AddressList);
-    d->addressList.clear();
-}
-
 bool AddressList::isEmpty() const
 {
     return d_func()->addressList.isEmpty();
@@ -562,6 +544,12 @@ Types::Mailbox::List AddressList::mailboxes() const
     return rv;
 }
 
+void AddressList::setAddressList(const Types::AddressList &addresses)
+{
+    Q_D(AddressList);
+    d->addressList = addresses;
+}
+
 bool AddressList::parse(const char *&scursor, const char *const send,
                         bool isCRLF)
 {
@@ -595,12 +583,6 @@ QByteArray Token::as7BitString(bool withHeaderType) const
     return d_func()->token;
 }
 
-void Token::clear()
-{
-    Q_D(Token);
-    d->token.clear();
-}
-
 bool Token::isEmpty() const
 {
     return d_func()->token.isEmpty();
@@ -620,7 +602,7 @@ void Token::setToken(const QByteArray &t)
 bool Token::parse(const char *&scursor, const char *const send, bool isCRLF)
 {
     Q_D(Token);
-    clear();
+    d->token.clear();
     eatCFWS(scursor, send, isCRLF);
     // must not be empty:
     if (scursor == send) {
@@ -679,12 +661,6 @@ QString PhraseList::asUnicodeString() const
   return d_func()->phraseList.join(QLatin1StringView(", "));
 }
 
-void PhraseList::clear()
-{
-    Q_D(PhraseList);
-    d->phraseList.clear();
-}
-
 bool PhraseList::isEmpty() const
 {
     return d_func()->phraseList.isEmpty();
@@ -760,12 +736,6 @@ QString DotAtom::asUnicodeString() const
     return QString::fromLatin1(d_func()->dotAtom);
 }
 
-void DotAtom::clear()
-{
-    Q_D(DotAtom);
-    d->dotAtom.clear();
-}
-
 bool DotAtom::isEmpty() const
 {
     return d_func()->dotAtom.isEmpty();
@@ -775,12 +745,12 @@ bool DotAtom::parse(const char *&scursor, const char *const send,
                     bool isCRLF)
 {
     Q_D(DotAtom);
-    QByteArray maybeDotAtom;
+    QByteArrayView maybeDotAtom;
     if (!parseDotAtom(scursor, send, maybeDotAtom, isCRLF)) {
         return false;
     }
 
-    d->dotAtom = maybeDotAtom;
+    d->dotAtom = maybeDotAtom.toByteArray();
 
     eatCFWS(scursor, send, isCRLF);
     if (scursor != send) {
@@ -856,12 +826,6 @@ bool Parametrized::isEmpty() const
     return d_func()->parameterHash.empty();
 }
 
-void Parametrized::clear()
-{
-    Q_D(Parametrized);
-    d->parameterHash.clear();
-}
-
 bool Parametrized::parse(const char  *&scursor, const char *const send,
                          bool isCRLF)
 {
@@ -911,13 +875,6 @@ QByteArray Ident::as7BitString(bool withHeaderType) const
     return rv;
 }
 
-void Ident::clear()
-{
-    Q_D(Ident);
-    d->msgIdList.clear();
-    d->cachedIdentifier.clear();
-}
-
 bool Ident::isEmpty() const
 {
     return d_func()->msgIdList.isEmpty();
@@ -1083,13 +1040,6 @@ QByteArray ReturnPath::as7BitString(bool withHeaderType) const
     return rv;
 }
 
-void ReturnPath::clear()
-{
-    Q_D(ReturnPath);
-    d->mailbox.setAddress(Types::AddrSpec());
-    d->mailbox.setName(QString());
-}
-
 bool ReturnPath::isEmpty() const
 {
     const Q_D(ReturnPath);
@@ -1166,14 +1116,6 @@ Generic::~Generic()
     d_ptr = nullptr;
 }
 
-void Generic::clear()
-{
-    Q_D(Generic);
-    delete[] d->type;
-    d->type = nullptr;
-    Unstructured::clear();
-}
-
 bool Generic::isEmpty() const
 {
     return d_func()->type == nullptr || Unstructured::isEmpty();
@@ -1239,13 +1181,6 @@ QByteArray Control::as7BitString(bool withHeaderType) const
     return rv;
 }
 
-void Control::clear()
-{
-    Q_D(Control);
-    d->name.clear();
-    d->parameter.clear();
-}
-
 bool Control::isEmpty() const
 {
     return d_func()->name.isEmpty();
@@ -1276,7 +1211,8 @@ void Control::setCancel(const QByteArray &msgid)
 bool Control::parse(const char *&scursor, const char *const send, bool isCRLF)
 {
     Q_D(Control);
-    clear();
+    d->name.clear();
+    d->parameter.clear();
     eatCFWS(scursor, send, isCRLF);
     if (scursor == send) {
         return false;
@@ -1332,14 +1268,6 @@ QString MailCopiesTo::asUnicodeString() const
     return {};
 }
 
-void MailCopiesTo::clear()
-{
-    Q_D(MailCopiesTo);
-    AddressList::clear();
-    d->alwaysCopy = false;
-    d->neverCopy = false;
-}
-
 bool MailCopiesTo::isEmpty() const
 {
     return AddressList::isEmpty() && !(d_func()->alwaysCopy || d_func()->neverCopy);
@@ -1353,7 +1281,8 @@ bool MailCopiesTo::alwaysCopy() const
 void MailCopiesTo::setAlwaysCopy()
 {
     Q_D(MailCopiesTo);
-    clear();
+    d->addressList.clear();
+    d->neverCopy = false;
     d->alwaysCopy = true;
 }
 
@@ -1365,7 +1294,8 @@ bool MailCopiesTo::neverCopy() const
 void MailCopiesTo::setNeverCopy()
 {
     Q_D(MailCopiesTo);
-    clear();
+    d->addressList.clear();
+    d->alwaysCopy = false;
     d->neverCopy = true;
 }
 
@@ -1373,7 +1303,9 @@ bool MailCopiesTo::parse(const char  *&scursor, const char *const send,
                          bool isCRLF)
 {
     Q_D(MailCopiesTo);
-    clear();
+    d->addressList.clear();
+    d->alwaysCopy = false;
+    d->neverCopy = false;
     if (send - scursor == 5) {
         if (qstrnicmp("never", scursor, 5) == 0) {
             d->neverCopy = true;
@@ -1419,11 +1351,6 @@ QByteArray Date::as7BitString(bool withHeaderType) const
     return rv;
 }
 
-void Date::clear() {
-    Q_D(Date);
-    d->dateTime = QDateTime();
-}
-
 bool Date::isEmpty() const {
     return d_func()->dateTime.isNull() || !d_func()->dateTime.isValid();
 }
@@ -1486,11 +1413,6 @@ QString Newsgroups::asUnicodeString() const {
     return QString::fromUtf8(as7BitString(false));
 }
 
-void Newsgroups::clear() {
-    Q_D(Newsgroups);
-    d->groups.clear();
-}
-
 bool Newsgroups::isEmpty() const {
     return d_func()->groups.isEmpty();
 }
@@ -1508,7 +1430,7 @@ bool Newsgroups::isCrossposted() const {
 
 bool Newsgroups::parse(const char *&scursor, const char *const send, bool isCRLF) {
     Q_D(Newsgroups);
-    clear();
+    d->groups.clear();
     while (true) {
       eatCFWS(scursor, send, isCRLF);
       if (scursor != send && *scursor == ',') {
@@ -1557,11 +1479,6 @@ QString Lines::asUnicodeString() const {
     return QString::number(d_func()->lines);
 }
 
-void Lines::clear() {
-    Q_D(Lines);
-    d->lines = -1;
-}
-
 bool Lines::isEmpty() const {
     return d_func()->lines == -1;
 }
@@ -1579,7 +1496,7 @@ bool Lines::parse(const char *&scursor, const char *const send, bool isCRLF) {
     Q_D(Lines);
     eatCFWS(scursor, send, isCRLF);
     if (parseDigits(scursor, send, d->lines)  == 0) {
-        clear();
+        d->lines = -1;
         return false;
     }
     return true;
@@ -1598,12 +1515,6 @@ bool ContentType::isEmpty() const {
     return d_func()->mimeType.isEmpty();
 }
 
-void ContentType::clear() {
-    Q_D(ContentType);
-    d->mimeType.clear();
-    Parametrized::clear();
-}
-
 QByteArray ContentType::as7BitString(bool withHeaderType) const {
     if (isEmpty()) {
       return {};
@@ -1765,7 +1676,8 @@ bool ContentType::parse(const char *&scursor, const char *const send,
                         bool isCRLF) {
     Q_D(ContentType);
     // content-type: type "/" subtype *(";" parameter)
-    clear();
+    d->mimeType.clear();
+    d->parameterHash.clear();
     eatCFWS(scursor, send, isCRLF);
     if (scursor == send) {
         return false; // empty header
@@ -1857,7 +1769,7 @@ bool ContentID::parse(const char *&scursor, const char *const send, bool isCRLF)
             }
 
             // Save chars until '>''
-            QByteArray result;
+            QByteArrayView result;
             if (!parseDotAtom(scursor, send, result, false)) {
                 return false;
             }
@@ -1897,58 +1809,74 @@ kmime_mk_trivial_ctor_with_name_and_dptr(ContentTransferEncoding,
         Generics::Token, Content-Transfer-Encoding)
 //@endcond
 
-struct encTableType {
+struct {
     const char *s;
-    int e;
-};
-
-static const encTableType encTable[] = {
+    contentEncoding e;
+} constexpr inline const encTable[] = {
     { "7Bit", CE7Bit },
     { "8Bit", CE8Bit },
     { "quoted-printable", CEquPr },
     { "base64", CEbase64 },
     { "x-uuencode", CEuuenc },
     { "binary", CEbinary },
-    { nullptr, 0}
 };
 
-void ContentTransferEncoding::clear() {
-    Q_D(ContentTransferEncoding);
-    d->cte = CE7Bit;
-    Token::clear();
+bool ContentTransferEncoding::isEmpty() const
+{
+    return false;
 }
 
-contentEncoding ContentTransferEncoding::encoding() const {
+QByteArray ContentTransferEncoding::as7BitString(bool withHeaderType) const
+{
+    Q_D(const ContentTransferEncoding);
+
+    if (d->token.isEmpty()) {
+        for (const auto &enc : encTable) {
+            if (d->cte == enc.e) {
+                return withHeaderType ? typeIntro() + enc.s : QByteArray(enc.s);
+            }
+        }
+    }
+
+    return withHeaderType ? typeIntro() + d->token : d->token;
+}
+
+contentEncoding ContentTransferEncoding::encoding() const
+{
     return d_func()->cte;
 }
 
-void ContentTransferEncoding::setEncoding(contentEncoding e) {
+void ContentTransferEncoding::setEncoding(contentEncoding e)
+{
     Q_D(ContentTransferEncoding);
     d->cte = e;
-
-    for (int i = 0; encTable[i].s != nullptr; ++i) {
-        if (d->cte == encTable[i].e) {
-            setToken(encTable[i].s);
-            break;
-        }
-    }
+    d->token.clear();
 }
 
-bool ContentTransferEncoding::parse(const char  *&scursor,
-                                    const char *const send, bool isCRLF) {
+bool ContentTransferEncoding::parse(const char  *&scursor, const char *const send, bool isCRLF)
+{
     Q_D(ContentTransferEncoding);
-    clear();
-    if (!Token::parse(scursor, send, isCRLF)) {
+    setEncoding(CE7Bit);
+
+    eatCFWS(scursor, send, isCRLF);
+    // must not be empty:
+    if (scursor == send) {
         return false;
     }
 
-    // TODO: error handling in case of an unknown encoding?
-    for (int i = 0; encTable[i].s != nullptr; ++i) {
-        if (qstricmp(token().constData(), encTable[i].s) == 0) {
-            d->cte = (contentEncoding)encTable[i].e;
-            break;
+    QByteArrayView token;
+    if (!parseToken(scursor, send, token, ParseTokenNoFlag)) {
+        return false;
+    }
+
+    for (const auto &enc : encTable) {
+        if (token.compare(enc.s, Qt::CaseInsensitive) == 0) {
+            d->cte = enc.e;
+            return true;
         }
     }
+
+    d->token = token.toByteArray();
     return true;
 }
 
@@ -1990,12 +1918,6 @@ bool ContentDisposition::isEmpty() const {
     return d_func()->disposition == CDInvalid;
 }
 
-void ContentDisposition::clear() {
-    Q_D(ContentDisposition);
-    d->disposition = CDInvalid;
-    Parametrized::clear();
-}
-
 contentDisposition ContentDisposition::disposition() const {
     return d_func()->disposition;
 }
@@ -2016,7 +1938,8 @@ void ContentDisposition::setFilename(const QString & filename) {
 bool ContentDisposition::parse(const char  *&scursor, const char *const send,
                                 bool isCRLF) {
     Q_D(ContentDisposition);
-    clear();
+    d->parameterHash.clear();
+    d->disposition = CDInvalid;
 
     // token
     eatCFWS(scursor, send, isCRLF);
@@ -2057,7 +1980,7 @@ bool ContentDisposition::parse(const char  *&scursor, const char *const send,
 kmime_mk_trivial_ctor_with_name(Subject, Generics::Unstructured, Subject)
 //@endcond
 
-Base *createHeader(const QByteArray & type) {
+Base *createHeader(QByteArrayView type) {
     return HeaderFactory::createHeader(type);
 }
 
